<?php

/**
 * Output a set of images for further use, e.g a slideshow, NivoSlider, lightbox gallery etc.
 *
 * Lots of setting possibilities incl. use of default instead of input, pagination etc.
 * See module description for more information (German only).
 *
 * @package Module
 * @subpackage OutputSetsOfImages
 * @version SVN Revision $Rev:$
 *
 * @author info@tone2tone.com
 * @copyright TONE2TONE e.K., Viktor Lehmann
 * @link http://www.tone2tone.com
 * Thanks to creators of former similar modules for code snippets and ideas
 */

// Prepare module info. Needed later to check if defined default smarty template is a real file 
$mod = new cApiModule($cCurrentModule);
$tplpath = $cfgClient[$client]["path"]["frontend"]."data/modules/".$mod->get("alias")."/template/";


// default values, in case input area is not configured or shall not be used
// not all values shown below make sense, please configure properly to your own needs 
$default_sPath            = "bilder_header/"; // don't forget slash at the end!
$default_columns          = 4; // set to high value if you need all images on one page, e.g. for sliders oder slideshows
$default_rows             = 3; // set to high value if you need all images on one page, e.g. for sliders oder slideshows
$default_max_width_scale  = 150;
$default_max_height_scale = 150;
$default_max_width_crop   = 90;
$default_max_height_crop  = 90;
$default_max_width_popup  = 900;
$default_max_height_popup = 600;
$default_sort             = "ASC"; // or "DESC"
$default_randomizer       = "no"; // or "yes"
$default_sTpl             = "lightbox_gallery_thumbs_popup.tpl"; // no slash at the end!
$default_extensions       = "'jpg', 'jpeg', 'gif', 'png'";
$forceDirectoryDefault    = false; // or false. Fills directory value below with default if set to true, ignoring the input value
$forceTemplateDefault     = true;  // or false. Fills template variable below with default if set to true, ignoring the input value
$forceSettingsDefault     = true;  // or false. Fills all other variables below with default if set to true, ignoring the input values

// get input variables or fill with defaults if forced through settings above
$sPath            = ( $forceDirectoryDefault ) ? $default_sPath            : "CMS_VALUE[4]";
$columns          = ( $forceSettingsDefault )  ? $default_columns          : "CMS_VALUE[2]";
$rows             = ( $forceSettingsDefault )  ? $default_rows             : "CMS_VALUE[3]";
$max_width_scale  = ( $forceSettingsDefault )  ? $default_max_width_scale  : "CMS_VALUE[0]";
$max_height_scale = ( $forceSettingsDefault )  ? $default_max_height_scale : "CMS_VALUE[1]";
$max_width_crop   = ( $forceSettingsDefault )  ? $default_max_width_crop   : "CMS_VALUE[7]";
$max_height_crop  = ( $forceSettingsDefault )  ? $default_max_height_crop  : "CMS_VALUE[8]";
$max_width_popup  = ( $forceSettingsDefault )  ? $default_max_width_popup  : "CMS_VALUE[10]";
$max_height_popup = ( $forceSettingsDefault )  ? $defaultmax_height_popup  : "CMS_VALUE[11]";
$sort             = ( $forceSettingsDefault )  ? $default_sort             : "CMS_VALUE[5]";
$randomizer       = ( $forceSettingsDefault )  ? $default_randomizer       : "CMS_VALUE[9]";
$sTpl             = ( $forceTemplateDefault )  ? $default_sTpl             : "CMS_VALUE[12]";


// check if input values are configured. If not, take defaults
// if not both of a scaling/cropping/popup input fields are set, assume this action shall not be taken, do not render images later
// even if a field is not set or 0, fill it with default later, as it will be used if ONE of the two fields is set
// e.g. in input: crop_width is set, crop_height not -> crop_height will take default value and image will be rendered.
$dirpath_shortest      = ( $sPath != "") ? $sPath : $default_sPath;
$dirpath_short         = ( $sPath != "") ? $cfgClient[$client]["upload"].$sPath : $cfgClient[$client]["upload"].$default_sPath;
$sTpl                  = ( $sTpl != "")  ? $sTpl : $default_sTpl;
$sort                  = ( $sort != "")  ? $sort : $default_sort;
$randomizer            = ( $randomizer != "") ? $randomizer : $default_randomizer;
$check_max_width_scale = true; if ( $max_width_scale == "" || $max_width_scale == 0 ) $check_max_width_scale = false; 
if ( $columns == "" || $columns == 0 ) $columns = $default_columns;
if ( $rows == "" || $rows == 0 ) $rows = $default_rows;

$check_max_width_scale  = true; if ( $max_width_scale  == "" || $max_width_scale  == 0 ) $check_max_width_scale  = false; 
$check_max_height_scale = true; if ( $max_height_scale == "" || $max_height_scale == 0 ) $check_max_height_scale = false; 
$check_max_width_crop   = true; if ( $max_width_crop   == "" || $max_width_crop   == 0 ) $check_max_width_crop   = false; 
$check_max_height_crop  = true; if ( $max_height_crop  == "" || $max_height_crop  == 0 ) $check_max_height_crop  = false; 
$check_max_width_popup  = true; if ( $max_width_popup  == "" || $max_width_popup  == 0 ) $check_max_width_popup  = false; 
$check_max_height_popup = true; if ( $max_height_popup == "" || $max_height_popup == 0 ) $check_max_height_popup = false; 
if ( !$check_max_width_scale )  $max_width_scale  = $default_max_width_scale;
if ( !$check_max_height_scale ) $max_height_scale = $default_max_height_scale;
if ( !$check_max_width_crop )   $max_width_crop   = $default_max_width_crop;
if ( !$check_max_height_crop )  $max_height_crop  = $default_max_height_crop;
if ( !$check_max_width_popup )  $max_width_popup  = $default_max_width_popup;
if ( !$check_max_height_popup ) $max_height_popup = $default_max_height_popup;

// check, which versions of new images shall be processed at all
// if no settings for both width and height are set, there will be no processing
$do_scale = ( !$check_max_width_scale && !$check_max_height_scale ) ? false : true;
$do_crop  = ( !$check_max_width_crop  && !$check_max_height_crop  ) ? false : true;
$do_popup = ( !$check_max_width_popup && !$check_max_height_popup ) ? false : true;
$shuffle  = ( $randomizer == "yes" ) ? true : false;

// Determine total amount of pictures for this page
$imagesPerPage = $columns * $rows;

// define additional variables
$uploadpath = $cfgClient[$client]["path"]["frontend"] . $cfgClient[$client]["upload"];
$search_conditions = 'dirname="'.$dirpath_shortest.'" AND LOWER(filetype) IN('.$default_extensions.')';
$search_order = "filename ".$sort;

// start pagination here already, as the flexselect request later on has to make use of startentry
// build pagination system
$oPaginationColl = new cApiUploadCollection();
$oPaginationColl->flexSelect('filename', '', $search_conditions, '', $search_order, '');
$numbermainentries = $oPaginationColl->count();
$numberofpages = ceil( $numbermainentries/$imagesPerPage );
if ( !isset($_GET["pagination"]) || $_GET["pagination"] == "" || $_GET["pagination"] <= 0  || $_GET["pagination"] > $numberofpages ) $actualpage = 1; else $actualpage = $_GET["pagination"];
$startentry = ($actualpage-1) * $imagesPerPage;

$pagination = array();
for ( $i=1; $i <= $numberofpages; $i++ ) {
	
	$pagination[$i]["class"] = ( $i == $actualpage ) ? "actualpage" : "";
	$pagination[$i]["page"]  = $i;
}

$pictures = array();

// run the statement
$search_limit = $startentry. ", ".$imagesPerPage;
$oUploadColl  = new cApiUploadCollection();
$oUploadColl->flexSelect('filename', '', $search_conditions, '', $search_order, $search_limit );

// build pictures array
while ($oUploadItem = $oUploadColl->next()) {
	
	$count++;
	
	$aImgData['filename'] = $oUploadItem->get('filename');
	$aImgData['source'] = $dirpath_short . $oUploadItem->get('filename');
	
	// if scaling parameters are set -> crop the scaled image, if not -> crop the original
	// if/then settings are complicated to force the system to ONLY render necessary images as this needs lots of resources and slows the system down

	$aImgData['thumb'] = ( $do_scale == true ) ? cApiImgScale($aImgData['source'], $max_width_scale, $max_height_scale, false, false) : $aImgData['source'];
	if ( $do_crop && $do_scale ) {
			$sScaledImage_cr   = str_replace($cfgClient[$client]["path"]["htmlpath"],"", $aImgData['thumb']);
			$aImgData['thumb'] = cApiImgScale($sScaledImage_cr, $max_width_crop, $max_height_crop, true, true) ;
	}
	if ( $do_crop && !$do_scale ) {
			$aImgData['thumb'] = cApiImgScale($aImgData['source'], $max_width_crop, $max_height_crop, true, true);
	}
	$aImgData['popup']         = ( $do_popup == true ) ? cApiImgScale($aImgData['source'], $max_width_popup, $max_height_popup, false, false) : $aImgData['source'];
	$aImgData['size']          = $oUploadItem->get('size');
	$aImgData['filetype']      = $oUploadItem->get('filetype');
	$aImgData['created']       = $oUploadItem->get('created');
	$aImgData['lastmodified']  = $oUploadItem->get('lastmodified');

	// delete html-path from links (existing after a imgScale procedure), IMHO not necessary and makes use of "list"-function easier:
	$aImgData['original']      = str_replace($cfgClient[$client]["path"]["htmlpath"],"", $aImgData['original']);
	$aImgData['thumb']         = str_replace($cfgClient[$client]["path"]["htmlpath"],"", $aImgData['thumb']);
	$aImgData['popup']         = str_replace($cfgClient[$client]["path"]["htmlpath"],"", $aImgData['popup']);
	
	
	// get dimensions of all new images
	list($aImgData['sourceWidth'], $aImgData['sourceHeight'], $aImgData['sourceType'], $aImgData['sourceAttributes']) = getimagesize($aImgData['source']);
	list($aImgData['thumbWidth'], $aImgData['thumbHeight'], $aImgData['thumbType'], $aImgData['thumbAttributes'])     = getimagesize($aImgData['thumb']);
	list($aImgData['popupWidth'], $aImgData['popupHeight'], $aImgData['popupType'], $aImgData['popupAttributes'])     = getimagesize($aImgData['popup']);
	
	// get metatags for the source image
	$meta = new cApiUploadMeta();
	$meta->loadByUploadIdAndLanguageId( $oUploadItem->get('idupl'), $lang );
	$aImgData['medianame']            = $meta->get('medianame');
	$aImgData['description']          = $meta->get('description');
	$aImgData['copyright']            = $meta->get('copyright');
	$aImgData['keywords']             = $meta->get('keywords');
	$aImgData['internal_notice'] = $meta->get('internal_notice');
	
	// Find out if the end of a column has been reached. If so, add a classname to this data set 
	if ($count == ( $columns + 1) ) { $aImgData['newrow'] = "newrow"; $count = 1; } else { $aImgData['newrow'] = "";}
	
	
	// add new images array item
	array_push($pictures, $aImgData);
}

// shuffle/randomize, if required
// be aware that shuffling makes no sense if you go with pagination
if ( $shuffle ) shuffle($pictures);


if ( !empty($pictures) ) {
		
	if ( file_exists($tplpath.$sTpl) ) {

	$tpl = cSmartyFrontend::getInstance();
	$tpl->assign('error', $error);
	$tpl->assign('pictures', $pictures);
	$tpl->assign('pagination', $pagination);
	$tpl->assign('idart', $idart);
	$tpl->display($sTpl);
		
	} else {
	
	print mi18n("no_template_found");
		
	}
	
}

if ( $sPath == "" && $default_sPath == "" ) {
		print mi18n("no_directory_set");
}




?>